==> bootstrap4-toggle-3.3.0.tgz: package/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## Unreleased
- Outline button support [3.4.0]

## [3.3.0](https://github.com/gitbrent/bootstrap4-toggle/tree/v3.3.0) 2018-12-19
### [Full Changelog](https://github.com/gitbrent/bootstrap4-toggle/compare/v3.2.0...v3.3.0)
### Added
- New test created to compare core bootstrap sizes to bootstrap4-toggle
### Changed
- Introduced new `size` values that mirror bootstrap 4: (`lg`, `sm`, `xs`)
- Converted all css units from `px` to `rem`
- Properly added border on `light` button (moved from .toggle class)
### Removed
**DEPRECATED** Classic `size` values (`large`, `small`, `mini`)


## [3.2.0](https://github.com/gitbrent/bootstrap4-toggle/tree/v3.2.0) 2018-11-27
### [Full Changelog](https://github.com/gitbrent/bootstrap4-toggle/compare/v3.1.0...v3.2.0)
### Added
### Changed
- Removed permanent `active` state from "Off" label so mouse-over highlighting works the same as "On"
### Removed



## [3.1.0](https://github.com/gitbrent/bootstrap4-toggle/tree/v3.1.0) 2018-10-25
### [Full Changelog](https://github.com/gitbrent/bootstrap4-toggle/compare/v3.0.0...v3.1.0)
### Added
- `index.html` includes new section with dark mode colors
### Changed
- `index.html` now fully responsive, better menu, rearranged sections
- Tweaked `border` property to work with all backgrounds and colors
### Removed



## [3.0.0](https://github.com/gitbrent/bootstrap4-toggle/tree/v3.0.0) 2018-10-21
### [Full Changelog](https://github.com/gitbrent/bootstrap4-toggle/compare/v2.2.2...v3.0.0)
### Added
- Touch support
### Changed
- Implements Bootstrap 4 colors/styles
### Removed
- Old Bootstrap 2 files

[Unreleased]: https://github.com/gitbrent/bootstrap4-toggle/compare/v1.9.0...HEAD
[3.2.0]: https://github.com/gitbrent/bootstrap4-toggle/compare/v3.1.0...v3.2.0
[3.1.0]: https://github.com/gitbrent/bootstrap4-toggle/compare/v3.0.0...v3.1.0
[3.0.0]: https://github.com/gitbrent/bootstrap4-toggle/compare/v2.2.2...v3.0.0

==> bootstrap4-toggle-3.4.0.tgz: package/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## Unreleased

## [3.4.0](https://github.com/gitbrent/bootstrap4-toggle/tree/v3.4.0) 2019-01-03
### [Full Changelog](https://github.com/gitbrent/bootstrap4-toggle/compare/v3.3.0...v3.4.0)
### Added
- Outline button styles are now available
### Changed
- Updated to Bootstrap version 4.2.1

## [3.3.0](https://github.com/gitbrent/bootstrap4-toggle/tree/v3.3.0) 2018-12-19
### [Full Changelog](https://github.com/gitbrent/bootstrap4-toggle/compare/v3.2.0...v3.3.0)
### Added
- New test created to compare core bootstrap sizes to bootstrap4-toggle
### Changed
- Introduced new `size` values that mirror bootstrap 4: (`lg`, `sm`, `xs`)
- Converted all css units from `px` to `rem`
- Properly added border on `light` button (moved from .toggle class)
### Removed
**DEPRECATED** Classic `size` values (`large`, `small`, `mini`)


## [3.2.0](https://github.com/gitbrent/bootstrap4-toggle/tree/v3.2.0) 2018-11-27
### [Full Changelog](https://github.com/gitbrent/bootstrap4-toggle/compare/v3.1.0...v3.2.0)
### Added
### Changed
- Removed permanent `active` state from "Off" label so mouse-over highlighting works the same as "On"
### Removed



## [3.1.0](https://github.com/gitbrent/bootstrap4-toggle/tree/v3.1.0) 2018-10-25
### [Full Changelog](https://github.com/gitbrent/bootstrap4-toggle/compare/v3.0.0...v3.1.0)
### Added
- `index.html` includes new section with dark mode colors
### Changed
- `index.html` now fully responsive, better menu, rearranged sections
- Tweaked `border` property to work with all backgrounds and colors
### Removed



## [3.0.0](https://github.com/gitbrent/bootstrap4-toggle/tree/v3.0.0) 2018-10-21
### [Full Changelog](https://github.com/gitbrent/bootstrap4-toggle/compare/v2.2.2...v3.0.0)
### Added
- Touch support
### Changed
- Implements Bootstrap 4 colors/styles
### Removed
- Old Bootstrap 2 files

[Unreleased]: https://github.com/gitbrent/bootstrap4-toggle/compare/v1.9.0...HEAD
[3.2.0]: https://github.com/gitbrent/bootstrap4-toggle/compare/v3.1.0...v3.2.0
[3.1.0]: https://github.com/gitbrent/bootstrap4-toggle/compare/v3.0.0...v3.1.0
[3.0.0]: https://github.com/gitbrent/bootstrap4-toggle/compare/v2.2.2...v3.0.0
